import { Counter, Gauge } from 'prom-client';
export class MetricsTranslator {
    constructor(registry) {
        this.registry = registry;
    }
    hasNewLabels(existingMetric, newLabelNames) {
        const existingLabelNames = existingMetric.labelNames || [];
        return newLabelNames.some((label) => !existingLabelNames.includes(label));
    }
    translateMetric(metric) {
        const existingMetric = this.registry.getSingleMetric(metric.name);
        const allLabelNames = new Set();
        for (const sample of metric.samples) {
            if (sample.labels) {
                Object.keys(sample.labels).forEach((label) => allLabelNames.add(label));
            }
        }
        const labelNames = Array.from(allLabelNames);
        if (metric.type === 'counter') {
            let counter;
            if (existingMetric && existingMetric instanceof Counter) {
                if (this.hasNewLabels(existingMetric, labelNames)) {
                    this.registry.removeSingleMetric(metric.name);
                    counter = new Counter({
                        name: metric.name,
                        help: metric.help,
                        registers: [this.registry],
                        labelNames,
                    });
                }
                else {
                    counter = existingMetric;
                }
            }
            else {
                counter = new Counter({
                    name: metric.name,
                    help: metric.help,
                    registers: [this.registry],
                    labelNames,
                });
            }
            for (const sample of metric.samples) {
                if (sample.labels) {
                    counter.inc(sample.labels, sample.value);
                }
                else {
                    counter.inc(sample.value);
                }
            }
            return counter;
        }
        else if (metric.type === 'gauge') {
            let gauge;
            if (existingMetric && existingMetric instanceof Gauge) {
                if (this.hasNewLabels(existingMetric, labelNames)) {
                    this.registry.removeSingleMetric(metric.name);
                    gauge = new Gauge({
                        name: metric.name,
                        help: metric.help,
                        registers: [this.registry],
                        labelNames,
                    });
                }
                else {
                    gauge = existingMetric;
                }
            }
            else {
                gauge = new Gauge({
                    name: metric.name,
                    help: metric.help,
                    registers: [this.registry],
                    labelNames,
                });
            }
            for (const sample of metric.samples) {
                if (sample.labels) {
                    gauge.set(sample.labels, sample.value);
                }
                else {
                    gauge.set(sample.value);
                }
            }
            return gauge;
        }
        return null;
    }
    translateMetrics(metrics) {
        for (const metric of metrics) {
            this.translateMetric(metric);
        }
        return this.registry;
    }
    serializeMetrics() {
        return this.registry.metrics();
    }
    translateAndSerializeMetrics(metrics) {
        this.translateMetrics(metrics);
        return this.serializeMetrics();
    }
}
//# sourceMappingURL=metrics-translator.js.map