export class FakeUnknownFlagsStore {
    constructor() {
        this.unknownFlagMap = new Map();
    }
    getKey(flag) {
        return `${flag.name}:${flag.appName}`;
    }
    async replaceAll(flags) {
        this.unknownFlagMap.clear();
        for (const flag of flags) {
            this.unknownFlagMap.set(this.getKey(flag), flag);
        }
    }
    async getAll() {
        return Array.from(this.unknownFlagMap.values());
    }
    async clear(hoursAgo) {
        const cutoff = Date.now() - hoursAgo * 60 * 60 * 1000;
        for (const [key, flag] of this.unknownFlagMap.entries()) {
            if (flag.seenAt.getTime() < cutoff) {
                this.unknownFlagMap.delete(key);
            }
        }
    }
    async deleteAll() {
        this.unknownFlagMap.clear();
    }
    async count() {
        return this.unknownFlagMap.size;
    }
}
//# sourceMappingURL=fake-unknown-flags-store.js.map