import type { FromSchema } from 'json-schema-to-ts';
export declare const customMetricsSchema: {
    readonly $id: "#/components/schemas/customMetricsSchema";
    readonly type: "object";
    readonly required: readonly ["metrics"];
    readonly description: "A collection of custom metrics";
    readonly properties: {
        readonly metrics: {
            readonly type: "array";
            readonly description: "Array of custom metrics";
            readonly items: {
                readonly $ref: "#/components/schemas/customMetricSchema";
            };
        };
    };
    readonly components: {
        readonly schemas: {
            readonly customMetricSchema: {
                $id: string;
                type: "object";
                required: string[];
                description: string;
                properties: {
                    name: {
                        type: "string";
                        description: string;
                        example: string;
                    };
                    value: {
                        type: "number";
                        description: string;
                        example: number;
                    };
                    labels: {
                        type: "object";
                        description: string;
                        additionalProperties: {
                            type: "string";
                        };
                        example: {
                            status: string;
                            method: string;
                        };
                    };
                };
                components: {};
            };
            readonly dateSchema: {
                readonly $id: "#/components/schemas/dateSchema";
                readonly description: "A representation of a date. Either as a date-time string or as a UNIX timestamp.";
                readonly oneOf: readonly [{
                    readonly type: "string";
                    readonly format: "date-time";
                    readonly description: "An [RFC-3339](https://www.rfc-editor.org/rfc/rfc3339.html)-compliant timestamp.";
                    readonly example: "2023-07-27T11:23:44Z";
                }, {
                    readonly type: "integer";
                    readonly description: "A [UNIX timestamp](https://en.wikipedia.org/wiki/Unix_time).";
                    readonly example: 1690449593;
                }];
                readonly components: {};
            };
        };
    };
};
export type CustomMetricsSchema = FromSchema<typeof customMetricsSchema>;
//# sourceMappingURL=custom-metrics-schema.d.ts.map