import type { FromSchema } from 'json-schema-to-ts';
export declare const impactMetricsSchema: {
    readonly $id: "#/components/schemas/impactMetricsSchema";
    readonly type: "object";
    readonly required: readonly ["name", "help", "type", "samples"];
    readonly description: "Used for reporting impact metrics from SDKs";
    readonly properties: {
        readonly name: {
            readonly type: "string";
            readonly description: "Name of the impact metric";
            readonly example: "my-counter";
        };
        readonly help: {
            readonly description: "Human-readable description of what the metric measures";
            readonly type: "string";
            readonly example: "Counts the number of operations";
        };
        readonly type: {
            readonly description: "Type of the metric";
            readonly type: "string";
            readonly enum: readonly ["counter", "gauge"];
            readonly example: "counter";
        };
        readonly samples: {
            readonly description: "Samples of the metric";
            readonly type: "array";
            readonly items: {
                readonly type: "object";
                readonly required: readonly ["value"];
                readonly description: "A sample of a metric with a value and optional labels";
                readonly properties: {
                    readonly value: {
                        readonly type: "number";
                        readonly description: "The value of the metric sample";
                        readonly example: 10;
                    };
                    readonly labels: {
                        readonly description: "Optional labels for the metric sample";
                        readonly type: "object";
                        readonly additionalProperties: {
                            readonly type: "string";
                        };
                        readonly example: {
                            readonly application: "my-app";
                            readonly environment: "production";
                        };
                    };
                };
            };
        };
    };
    readonly components: {
        readonly schemas: {};
    };
};
export type ImpactMetricsSchema = FromSchema<typeof impactMetricsSchema>;
//# sourceMappingURL=impact-metrics-schema.d.ts.map