import dbInit from '../../../helpers/database-init.js';
import { setupAppWithCustomConfig, } from '../../../helpers/test-helper.js';
import getLogger from '../../../../fixtures/no-logger.js';
let app;
let db;
let apiTokenStore;
beforeAll(async () => {
    db = await dbInit('projects_api_serial', getLogger);
    app = await setupAppWithCustomConfig(db.stores, {
        experimental: {
            flags: {
                strictSchemaValidation: true,
            },
        },
    }, db.rawDatabase);
    apiTokenStore = db.stores.apiTokenStore;
});
afterAll(async () => {
    await app.destroy();
    await db.destroy();
});
test('Should always return token type in lowercase', async () => {
    await apiTokenStore.insert({
        environment: '*',
        alias: 'some-alias',
        secret: 'some-secret',
        type: 'FRONTEND',
        projects: ['default'],
        tokenName: 'some-name',
    });
    const storedToken = await apiTokenStore.get('some-secret');
    expect(storedToken.type).toBe('frontend');
    const { body } = await app.request
        .get('/api/admin/projects/default/api-tokens')
        .expect(200)
        .expect('Content-Type', /json/);
    expect(body.tokens).toHaveLength(1);
    expect(body.tokens[0].type).toBe('frontend');
});
//# sourceMappingURL=api-token.e2e.test.js.map